.. _install:

Installation
============

MotifScan is written in Python with C extensions, it supports Python 3.6+.

The sections below show how to install the latest release of MotifScan.


Install from PyPI
-----------------
The latest release of MotifScan is available at PyPI_, you can install via ``pip``:

.. code-block:: shell

    $ pip install -U motifscan

Install with conda
------------------

You can also install MotifScan with conda_ through Bioconda_ channel:

.. code-block:: shell

   $ conda install -c bioconda motifscan

.. _PyPI: https://pypi.org/project/motifscan
.. _conda: https://conda.io
.. _Bioconda: https://bioconda.github.io
